@@ -13,18 +13,20 @@ class Cron:
 
     def off(self):
         if not self.enabled():
-            raise Exception('already disabled')
+            return 'already disabled'
         else:
             cmd = "crontab -l | sed '/{}/d' | crontab -".format(self.main_script_name)
             system(cmd)
+            return 'disabled'
 
     def on(self):
         if self.enabled():
-            raise Exception('already enabled')
+            return 'already enabled'
         else:
             cmd = "{0} sync_all > {1} 2>&1".format(self.command_line, self.log_path)
             crontab_cmd = "(crontab -l; echo \"*/{} * * * * {}\") | crontab -".format(self.period_mins, cmd)
             system(crontab_cmd)
+            return 'enabled'
 
     def enabled(self):
         cmd = "crontab -l | grep {} | wc -l".format(self.main_script_name)
