@@ -73,6 +73,8 @@ class Dns:
 
     def service_info(self, name):
         service = self.get_service(name)
+        if not service:
+            raise Exception("service not found: {0}".format(name))
         mapping = self.port_mapper.get(service.port)
         return Endpoint(service, self.full_name(), mapping.external_port)
 
