@@ -54,7 +54,7 @@ class TestDns(unittest.TestCase):
         {"name": "SSH", "protocol": "https", "type": "_http._tcp", "port": 10001, "url": null}
     ],
     "ip": "192.167.44.52",
-    "update_token": "some_update_token"
+    "token": "some_update_token"
 }
 '''
 
