@@ -1,6 +1,6 @@
 from ConfigParser import ConfigParser
 import unittest
-from subprocess import check_output, call
+from subprocess import check_output, call, CalledProcessError
 from os.path import dirname, join
 
 test_dir = dirname(__file__)
@@ -81,6 +81,18 @@ class TestCli(unittest.TestCase):
         self.assertTrue("\"external_port\": 10000" in output, output)
         self.assertTrue("\"external_host\": \"device.domain.localhost\"" in output, output)
 
+    def test_service_info_not_found(self):
+
+        copy_conf('domain.json')
+        copy_conf('ports.json')
+        copy_conf('services.json')
+
+        try:
+            output = check_output('{} service_info owncloud'.format(cmd), shell=True)
+            self.fail("should no succeed")
+        except CalledProcessError, e:
+            self.assertTrue("not found" in e.output, e.output)
+
     def tearDown(self):
         clean_up()
 
